@@ -19,7 +19,11 @@ from ddsp.training import data
 from ddsp.training import decoders
 from ddsp.training import encoders
 from ddsp.training import eval_util
+from ddsp.training import inference
+from ddsp.training import metrics
 from ddsp.training import models
 from ddsp.training import nn
 from ddsp.training import preprocessing
+from ddsp.training import summaries
 from ddsp.training import train_util
+from ddsp.training import trainers
